Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BEUint64 ¶
BEUint64 interprets b as an 8-byte big-endian value and returns it as a uint64. It requires len(b) >= 8.
func ConstantTimeCompare ¶
ConstantTimeCompare returns 1 if x and y are equal and 0 otherwise.
func ConstantTimeLessOrEqBytes ¶
ConstantTimeLessOrEqBytes returns 1 if x <= y and 0 otherwise. The comparison is lexicographical, or big-endian. The time taken is a function of the length of the slices and is independent of the contents. If the lengths of x and y do not match it returns 0 immediately.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.